RasterBuffer

Struct RasterBuffer 

pub struct RasterBuffer { /* private fields */ }
A typed buffer for raster data

Implementations

Source

impl RasterBuffer

pub fn new( data: Vec<u8>, width: u64, height: u64, data_type: RasterDataType, nodata: NoDataValue, ) -> Result<Self>

Creates a new raster buffer

Errors

Returns an error if the data size doesn’t match the dimensions and type

pub fn zeros(width: u64, height: u64, data_type: RasterDataType) -> Self

Creates a zero-filled buffer

pub fn nodata_filled( width: u64, height: u64, data_type: RasterDataType, nodata: NoDataValue, ) -> Self

Creates a buffer filled with the nodata value

pub fn fill_value(&mut self, value: f64)

Fills the buffer with a constant value

pub const fn width(&self) -> u64

Returns the width in pixels

pub const fn height(&self) -> u64

Returns the height in pixels

pub const fn data_type(&self) -> RasterDataType

Returns the data type

pub const fn nodata(&self) -> NoDataValue

Returns the nodata value

pub const fn pixel_count(&self) -> u64

Returns the total number of pixels

pub fn as_bytes(&self) -> &[u8]

Returns the raw bytes

pub fn as_bytes_mut(&mut self) -> &mut [u8]

Returns mutable raw bytes

pub fn into_bytes(self) -> Vec<u8>

Consumes the buffer and returns the raw bytes

pub fn from_typed_vec<T: Copy + 'static>( width: usize, height: usize, data: Vec<T>, data_type: RasterDataType, ) -> Result<Self>

Creates a buffer from typed vector data

Arguments
  • width - Width in pixels
  • height - Height in pixels
  • data - Typed data (e.g., Vec<f32>, Vec<u8>)
  • data_type - The raster data type
Errors

Returns an error if the data size doesn’t match dimensions and type

pub fn as_slice<T: Copy + 'static>(&self) -> Result<&[T]>

Returns the buffer data as a typed slice

Type Parameters
  • T - The target type (must match the buffer’s data type size)
Errors

Returns an error if the type size doesn’t match the data type

pub fn as_slice_mut<T: Copy + 'static>(&mut self) -> Result<&mut [T]>

Returns the buffer data as a mutable typed slice

Type Parameters
  • T - The target type (must match the buffer’s data type size)
Errors

Returns an error if the type size doesn’t match the data type

pub fn get_pixel(&self, x: u64, y: u64) -> Result<f64>

Gets a pixel value as f64

Errors

Returns an error if coordinates are out of bounds

pub fn set_pixel(&mut self, x: u64, y: u64, value: f64) -> Result<()>

Sets a pixel value

Errors

Returns an error if coordinates are out of bounds

pub fn is_nodata(&self, value: f64) -> bool

Returns true if the given value equals the nodata value

pub fn convert_to(&self, target_type: RasterDataType) -> Result<Self>

Converts the buffer to a different data type

Errors

Returns an error if conversion fails

pub fn compute_statistics(&self) -> Result<BufferStatistics>

Computes basic statistics