ByteRange

Struct ByteRange 

pub struct ByteRange {
    pub start: u64,
    pub end: u64,
}
Byte range for partial reads

Fields

start: u64

Start offset (inclusive)

end: u64

End offset (exclusive)

Implementations

Source

impl ByteRange

pub const fn new(start: u64, end: u64) -> Self

Creates a new byte range

pub const fn from_offset_length(offset: u64, length: u64) -> Self

Creates a byte range from an offset and length

pub const fn len(&self) -> u64

Returns the length of this range

pub const fn is_empty(&self) -> bool

Returns true if the range is empty

pub const fn overlaps(&self, other: &Self) -> bool

Returns true if this range overlaps with another

pub const fn is_adjacent(&self, other: &Self) -> bool

Returns true if this range is adjacent to another

pub fn merge(&self, other: &Self) -> Option<Self>

Merges two overlapping or adjacent ranges