StridedView

Struct StridedView 

pub struct StridedView<'a, T> { /* private fields */ }
A strided view into a buffer for accessing every nth element

Implementations

Source

impl<T> StridedView<'_, T>

pub fn len(&self) -> usize

Get the number of elements in the strided view

pub fn is_empty(&self) -> bool

Check if the view is empty

pub fn get(&self, index: usize) -> Option<&T>

Get an element at the specified index

pub fn iter(&self) -> StridedIterator<'_, T>

Create an iterator over the strided elements