pub struct ByteRange {
pub start: u64,
pub end: u64,
}Expand description
Byte range for partial reads
Fields
start: u64Start offset (inclusive)
end: u64End offset (exclusive)
Implementations
Sourceimpl ByteRange
impl ByteRange
Sourcepub const fn from_offset_length(offset: u64, length: u64) -> Self
pub const fn from_offset_length(offset: u64, length: u64) -> Self
Creates a byte range from an offset and length
Sourcepub const fn overlaps(&self, other: &Self) -> bool
pub const fn overlaps(&self, other: &Self) -> bool
Returns true if this range overlaps with another
Sourcepub const fn is_adjacent(&self, other: &Self) -> bool
pub const fn is_adjacent(&self, other: &Self) -> bool
Returns true if this range is adjacent to another